class SimpleSprite < AS::Scene::SpriteNode

	def initialize(tex, tiles = 1, select_tile = 0)
	
		hw = tex.w/(tiles)
		hh = tex.h
	
		crn = AS::Scene::CopyRectNode.new(tex, select_tile * hw,0,hw,hh,0,0,hw,hh) #(tex, sx, sy, sw, sh, dx, dy, dw, dh)

		#textureNode = AS::Scene::TextureNode.new(tex,  AS::Scene::DisplayListNode.new(AS::DisplayList.for_sprite(tex, tex.w, tex.h)))
		super(crn)
	end
	
end

JET_POWER = 15

class ForkliftSprite < AS::Scene::SpriteNode

	SPRITES_WIDE = 2
	OFFSET = vec2(0,0)
	
		
	attr_reader :body, :shape
	attr_writer :airborne
	
	
	def initialize
		@thisTex = GirlForklift
		
		w = @thisTex.w
		h = @thisTex.h
	
		hw = w/(2.0 * SPRITES_WIDE)
		hh = h/2.0
		
		@verts = [
						 vec2(-hw, -hh),
						 vec2(-hw,  hh),
						 vec2( hw,  hh),
						 vec2( hw, -hh),
						]	
						
						
		mass = 10
		moment = 1.0 / 0 #infinity!
		
		@body = CP::Body.new(mass, moment)
		@shape = CP::Shape::Poly.new(@body, @verts, OFFSET)
		@shape.collision_type = :player
		
		@body.p = vec2(50, 50)
		@shape.u = 2
	
		@airborne = false
		@jump_jets = 0

				
		super(AS::Scene::BodyNode.new(@body, basic_node))
	end
	
	def activate_jets
		if @jump_jets < 1 and !@airborne
			@jump_jets = JET_POWER 
			#change texture to: ForkliftJetTex
			setImage(1)
			airborne = true
		end
	end
	
	def setImage(i)
		dx = @thisTex.w/2.0
		@packed_matrix.matrix = AS::Transform2D.translate(dx * i, 0)
	end
	
	def jets_on?
		@jump_jets > 0
	end
	
	def update(input_pad)
		#for the first frame after landing, don't use the surface velocities.

		@shape.surface_v = vec2(input_pad[:zoom] * 270, 0)
	
		@body.v += vec2(-input_pad[:zoom] * 10, 0) if @jump_jets > 0 or @airborne
		
		@body.v += vec2(0, @jump_jets)
		
		if input_pad[:zoom] > 0
			@flipSprite.scale_x = -1
		elsif input_pad[:zoom] < 0
			@flipSprite.scale_x = 1
		end
		#flip horizontal if body.v.x < 0
		
		setImage(0) if @jump_jets == 1
		@jump_jets -= 1 if @jump_jets > 0
	end
	
	
	def basic_node
		w = @thisTex.w
		h = @thisTex.h
	  
		hw = w/(2 * SPRITES_WIDE)
		hh = h/2
	
		#we use the matrix to swap to the second image. (translate the GL:Texture to the second one in the list)
		@packed_matrix = AS::Transform2D.translate(0, 0).pack
		matrix_node = AS::Scene::MatrixNode.new(GL::TEXTURE, @packed_matrix){
			@flipSprite = AS::Scene::SpriteNode.new{
				AS::Scene::BlendNode.new(nil, GL::SRC_ALPHA, GL::ONE_MINUS_SRC_ALPHA){
					AS::Scene::CopyRectNode.new(@thisTex, 0,0,w/2,h,-hw,-hh,w/2,h) #(tex, sx, sy, sw, sh, dx, dy, dw, dh)
				}
			}
		}
		return matrix_node
	end

end
